==> hledger-1.32.1-37.1-riscv64.pkg.tar.zst: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hledger
version:              1.32.1
visibility:           public
id:                   hledger-1.32.1-Ay3qSheXnJO9xeE4fynKrB
key:                  hledger-1.32.1-Ay3qSheXnJO9xeE4fynKrB
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  61e78189140305863060d84a447ecf05
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anon Hledger.Cli.CliOptions
    Hledger.Cli.Commands Hledger.Cli.Commands.Accounts
    Hledger.Cli.Commands.Activity Hledger.Cli.Commands.Add
    Hledger.Cli.Commands.Aregister Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.DocFiles Hledger.Cli.Script Hledger.Cli.Utils
    Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hledger-1.32.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hledger-1.32.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.32.1-Ay3qSheXnJO9xeE4fynKrB
depends:
    Decimal-0.5.2-EH6F0LnkbjJTiXvVL2fyH
    Diff-0.4.1-2b84kELbdFiFT3I48y9pel
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    ansi-terminal-0.11.4-6jSb6ZqnQv5806EReMBETJ base-4.16.4.0
    bytestring-0.11.4.0 cmdargs-0.10.22-JQ4ivQZzeRmKKTWVSPDfjg
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    directory-1.3.6.2 extra-1.7.14-JZwVFNOTzAl9wNXhTRS6o8
    filepath-1.4.2.2 githash-0.1.6.3-QG9qVgClYmDbGPauDM8nx
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc haskeline-0.8.2
    hledger-lib-1.32.1-BymMs1AwG1aEOQosZw0BSW
    lucid-2.11.20230408-4lTvUuAHGJQ7LKqFnj5uvW
    math-functions-0.3.4.3-7HvxrIY8tVS9lDmC7YcP2m
    megaparsec-9.5.0-Bj42S1sxqz5CEZGEYlrAL4
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA mtl-2.2.2
    process-1.6.16.0 regex-tdfa-1.3.2.2-G7ufGPI8BXGB521OJBI0lU
    safe-0.3.21-4QyPpELCc0N1ZMTeAcwgiX
    shakespeare-2.1.0.1-Uy4jodBTwoFYAjbezW2JJ
    split-0.2.5-9vnWwbrKvb7KEkhm7eawnM
    tabular-0.2.2.8-95p3h1QIWwyCocci2BuF7w
    tasty-1.4.3-3WNUiw7s1TODR5TnJa9k2E
    temporary-1.3-7m2Oh4fRk7W729IUmkQcQs terminfo-0.4.1.5 text-1.2.5.0
    text-ansi-0.2.1.1-5UHLCCbxqiA7taHXXprFsa time-1.11.1.1
    timeit-2.0-FPerWVMxZElJkpHtTsXEJ4 transformers-0.5.6.2
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    utility-ht-0.0.17.1-FqmHeGUKM3tKzNxNCKDmdm
    wizards-1.0.3-614DR2XTBGc2LfYMK8q7fT

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-1.32.1-65-riscv64.pkg.tar.zst: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hledger
version:              1.32.1
visibility:           public
id:                   hledger-1.32.1-9h09rAhCjid6PWMfpnIhYE
key:                  hledger-1.32.1-9h09rAhCjid6PWMfpnIhYE
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  ae8fa0459699bf11163a54077608c143
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anon Hledger.Cli.CliOptions
    Hledger.Cli.Commands Hledger.Cli.Commands.Accounts
    Hledger.Cli.Commands.Activity Hledger.Cli.Commands.Add
    Hledger.Cli.Commands.Aregister Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.DocFiles Hledger.Cli.Script Hledger.Cli.Utils
    Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hledger-1.32.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hledger-1.32.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.32.1-9h09rAhCjid6PWMfpnIhYE
depends:
    Decimal-0.5.2-FZVdXLcePM2H7jSypcEkWe
    Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE base-4.16.4.0
    bytestring-0.11.4.0 cmdargs-0.10.22-JQ4ivQZzeRmKKTWVSPDfjg
    containers-0.6.5.1 data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9
    directory-1.3.6.2 extra-1.7.15-9PmwGQvWkElDwGNWrixqMB
    filepath-1.4.2.2 githash-0.1.6.3-IX1GqAmi93MLlgt20beGip
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r haskeline-0.8.2
    hledger-lib-1.32.1-93So1L5wGd9EWwe4MbIKLM
    lucid-2.11.20230408-E6neZ5sCnkr6dovH410yLu
    math-functions-0.3.4.4-bJIbxJm3ZnEvmNU4NREUw
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA mtl-2.2.2
    process-1.6.16.0 regex-tdfa-1.3.2.2-9KQuOdDpiBL9UBsQEK6k8E
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    shakespeare-2.1.0.1-Gbrqdks1NkK7A5fj5vxRJN
    split-0.2.5-L5qB0eGVSdY6HJmwsU4RMl
    tabular-0.2.2.8-95p3h1QIWwyCocci2BuF7w
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7
    temporary-1.3-92h1kCtCGR4FaQHxoGuxwh terminfo-0.4.1.5 text-1.2.5.0
    text-ansi-0.2.1.1-AXPowipAINbGO7p8EieRlm time-1.11.1.1
    timeit-2.0-FPerWVMxZElJkpHtTsXEJ4 transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX
    utility-ht-0.0.17.2-7hfxNAxwKoFLnCNbU4FWYa
    wizards-1.0.3-614DR2XTBGc2LfYMK8q7fT

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
